@@ -27,6 +27,9 @@
 #include "knapster.xpm"
 
 #include "extlineedit.h"
+#include "extlistbox.h"
+
+#include "propertiesdlg.h"
 
 /*
 class MEdit : public QMultiLineEdit
@@ -51,10 +54,15 @@ protected:
 ConsolePanel::ConsolePanel(QWidget *parent, const char *name )
 : QWidget(parent,name)
 {
+  Preferences p = PropertiesDlg::readPrefs();
+
   QGridLayout *grid=new QGridLayout(this,3,2,5,5);
 
-  consolewin=new QMultiLineEdit(this);
-  consolewin->setReadOnly(true);
+//  consolewin=new QMultiLineEdit(this);
+  consolewin = new ExtListBox(this);
+  consolewin->setCols(p.normalcol,p.infocol,p.messagecol,p.errorcol);
+
+//  consolewin->setReadOnly(true);
   grid->addMultiCellWidget(consolewin,1,1,0,1);
 
   commandwin=new ExtLineEdit(this);
@@ -72,11 +80,11 @@ ConsolePanel::~ConsolePanel()
 {
 }
 
-void ConsolePanel::writeString(QString s)
+void ConsolePanel::writeString(QString s,ExtListBox::LineType type)
 {
   if(!s.isNull()) {
-    consolewin->insertLine(s);
-    consolewin->setCursorPosition(consolewin->numLines(),0);
+    consolewin->insertLine(s,type);
+//    consolewin->setCursorPosition(consolewin->numLines(),0);
   }
   return;
 }
@@ -94,3 +102,10 @@ void ConsolePanel::calcCommand()
   commandwin->clear();
 }
 
+void ConsolePanel::setColors(
+   const QColor &norm,const QColor &info,const QColor &msg,const QColor &err)
+{
+   consolewin->setCols(norm,info,msg,err);
+}
+
+
