@@ -16,7 +16,7 @@
  ***************************************************************************/
 
 #include "downloadpanel.h"
-#include <qlistview.h>
+#include <extlistview.h>
 #include <qlayout.h>
 #include <qpopupmenu.h>
 #include <kapp.h>
@@ -31,9 +31,8 @@
 
 #include <stdlib.h>
 
-class DownloadListItem : public QListViewItem {
-//private:
-//  long bytesread,bytesize;
+class DownloadListItem : public QListViewItem
+{
 public:
   DownloadListItem(QListView *parent,const char *s1,const char *s2,const char *s3,
 		   const char *s4,const char *s5,const char *s6,const char *s7,const char *s8)
@@ -108,7 +107,7 @@ DownloadPanel::DownloadPanel(QWidget *parent, const char *name )
 //  stats->setMaximumHeight( stats->sizeHint().height() );
 //  grid->addWidget(stats,0,0);
 
-  downloadlistview=new QListView(this);
+  downloadlistview=new ExtListView(this,"downloadview");
   downloadlistview->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
   grid->addMultiCellWidget(downloadlistview,0,0,0,0);
 
@@ -128,6 +127,8 @@ DownloadPanel::DownloadPanel(QWidget *parent, const char *name )
   downloadlistview->addColumn("progress",80);
   downloadlistview->setColumnWidthMode(DLV_PROGRESS,QListView::Manual);
 
+  downloadlistview->loadWidths();
+
   // create the popup menu for the downloadlist view
   downloadpopupmenu=new QPopupMenu();
   if(downloadpopupmenu) {
@@ -138,7 +139,9 @@ DownloadPanel::DownloadPanel(QWidget *parent, const char *name )
     downloadpopupmenu->insertItem("Whois user",this,SLOT(popupWhois()));
 
     downloadpopupmenu->insertSeparator();
-    downloadpopupmenu->insertItem("terminate download",this,SLOT(popupDownloadTerminate()));
+    downloadpopupmenu->insertItem("Terminate download",this,SLOT(popupDownloadTerminate()));
+
+    downloadpopupmenu->insertItem("Terminate download and delete file",this,SLOT(popupDownloadTerminateAndDelete()));
   }
   connect(downloadlistview,SIGNAL(rightButtonPressed( QListViewItem *, const QPoint &, int )),
        this,SLOT(popupMenu( QListViewItem *, const QPoint &, int )));
@@ -183,6 +186,15 @@ void DownloadPanel::popupDownloadTerminate()
   }
 }
 
+void DownloadPanel::popupDownloadTerminateAndDelete()
+{
+  QListViewItem *selecteditem=downloadlistview->currentItem();
+
+  if(selecteditem) {
+     emit terminate_and_delete(selecteditem);
+  }
+}
+
 void DownloadPanel::clear()
 {
   downloadlistview->clear();
@@ -307,6 +319,9 @@ QString DownloadPanel::convertDownloadStatus(long s)
      case NapsterDownload::DL_NOLOCALFILE:
        str="No file";
        break;
+     case NapsterDownload::DL_TIMEOUT:
+       str="Timed out";
+       break;
      case NapsterDownload::DL_QUEUED:
        str="Queued";
        break;
