@@ -60,12 +60,6 @@ void ExtComboBox::keyPressEvent ( QKeyEvent * e )
    else lastchar = e->key();
 }
 
-/*void ExtComboBox::mousePressEvent ( QMouseEvent *e )
-{
-  QComboBox::mousePressEvent(e);
-  lastchar = 0;
-}*/
-
 void ExtComboBox::saveText()
 {
   /* add the value to the list - if its not there!!*/
@@ -92,7 +86,3 @@ QStrList ExtComboBox::history()
    }
    return str;
 }
-/*void ExtComboBox::setHistory(const QString &str)
-{
-
-}*/
