@@ -55,6 +55,8 @@
 #include "uploadpanel.h"
 #include "librarypanel.h"
 
+#include "exttab.h"
+
 #include <iostream.h>
 
 #include <stdio.h>
@@ -72,9 +74,11 @@ Knapster::Knapster(const char *name)
 #endif  
 
 #ifdef KDE2
+ config->readListEntry("recentconnection",recentConnection);
 #else
   // allow $ in the config file to read
   kapp->getConfig()->setDollarExpansion(false);
+  kapp->getConfig()->readListEntry("recentconnection",recentConnection);
 #endif
 
 
@@ -115,20 +119,11 @@ Knapster::Knapster(const char *name)
   if(timer) {
      connect(timer,SIGNAL(timeout()),this,SLOT(timeout()));
 
-     timer->start(2000); // update ever 2 second
+     timer->start(2000); // update every 2 second
   }
 
   writeConsole("KNapster " VERSION " - John Donoghue, 2000\ndonoghue@chariot.net.au\n");
 
-  // set up the past history
-  QStrList list(true);
-#ifdef KDE2
-  config->->readListEntry ("history",list);
-#else
-  kapp->getConfig()->readListEntry ("history",list);
-#endif
-  searchpanel->setSearchHistory(list);
-
 }
 
 Knapster::~Knapster()
@@ -152,26 +147,28 @@ void Knapster::closeDown()
       player.kill();
       return;
     }
+    searchpanel->saveSearchPrefs();
 
-    // save the past search history
-    QStrList str = searchpanel->getSearchHistory();
-#ifdef KDE2
-    config->writeEntry("history",str);
-#else
-    kapp->getConfig()->writeEntry("history",str);
-#endif
-
+    /* force the list views to save thier sizes */
+    delete downloadpanel;
+    delete uploadpanel;
+    delete searchpanel;
+    delete librarypanel;
 
 #ifdef KDE2
     config->writeEntry("winw",width());
     config->writeEntry("winh",height());
 
+    config->writeEntry("recentconnection",recentConnection);
+
     // force save
     config->sync();
 #else
     kapp->getConfig()->writeEntry("winw",width());
     kapp->getConfig()->writeEntry("winh",height());
 
+    kapp->getConfig()->writeEntry("recentconnection",recentConnection);
+
     // force save
     kapp->getConfig()->sync();
 #endif
@@ -185,10 +182,10 @@ void Knapster::setupTabs()
 {
   Preferences p=PropertiesDlg::readPrefs();
 
-  KTabCtl *tab=new KTabCtl(this);
+  tab=new ExtTab(this);
 
   // tab1 - console -------------------
-  console=new ConsolePanel(tab);
+  console=new ConsolePanel(tab,"console");
   connect(console,SIGNAL(command(const char *)),this,SLOT(startConsoleCommand(const char *)));
   tab->addTab(console,i18n("Console"));
 
@@ -210,6 +207,9 @@ void Knapster::setupTabs()
   connect(downloadpanel,SIGNAL(ping(const char *)),this,SLOT(addPingItem(const char *)));
   connect(downloadpanel,SIGNAL(whois(const char *)),this,SLOT(sendWhois(const char *)));
   connect(downloadpanel,SIGNAL(terminate(QListViewItem *)),this,SLOT(downloadTerminate(QListViewItem *)));
+	
+  connect(downloadpanel,SIGNAL(terminate_and_delete(QListViewItem *)),this,SLOT(downloadTerminateAndDelete(QListViewItem *)));
+	
   connect(downloadpanel,SIGNAL(play(const char *)),this,SLOT(playsong_dl(const char *)));
   tab->addTab(downloadpanel,i18n("Downloads"));
 
@@ -241,12 +241,21 @@ void Knapster::setupMenus()
   menuBar()->enableMoving(false);
 #endif /* KDE2 */
 
+  // prev connect menu
+  prevconnect_menu = new QPopupMenu();
+  connect(prevconnect_menu, SIGNAL(activated(int)), SLOT(menuOpenRecent(int)));
+  addRecentConnection("");
+
+//  prevconnect_menu->insertItem("102.103.33.0",7,0);
+//  prevconnect_menu->insertItem("102.103.33.1",0,1);
+
   // COnnect
   QPopupMenu *m=new QPopupMenu();
   m->insertItem(i18n("&LogOn/Off"),this,SLOT(menuLogon()));
   m->insertItem(i18n("&Relogin"),this,SLOT(menuRelogon()));
 //    m->insertSeparator();
-//  m->insertItem(i18n("&Connect to recent"),this,SLOT(menuRecent()));
+  m->insertItem(i18n("&Connect to recent"),prevconnect_menu);
+
     m->insertSeparator();
   m->insertItem(i18n("E&xit"),this,SLOT(closeDown()));
 
@@ -280,18 +289,68 @@ void Knapster::setupMenus()
 }
 
 // write a string to the console
-void Knapster::writeConsole(char *s)
+void Knapster::writeConsole(char *s,ExtListBox::LineType type)
 {
-  console->writeString(s);
+  console->writeString(s,type);
 }
 
 // write to the console - the QString version
-void Knapster::writeConsole(QString s)
+void Knapster::writeConsole(QString s,ExtListBox::LineType type)
 {
   // write text to the console window
-  console->writeString(s);
+  console->writeString(s,type);
 }
 
+// slot for slection of open recent
+void Knapster::menuOpenRecent(int pos)
+{
+#ifdef DEBUG_1
+   cerr<<"pos = "<<pos<<" to "<<recentConnection.at(pos)<<endl<<flush;
+#endif
+
+   if((unsigned int)pos<recentConnection.count())
+   {
+     // can't relogin if already connected
+     if(connection.isConnected()) {
+       writeConsole(i18n("Still connected?? - logoff first"),ExtListBox::Error);
+       return;
+     }
+     if(!connection.parseBestHostString(recentConnection.at(pos)))
+     {
+        writeConsole("***invalid ip/port in recent list",ExtListBox::Error);
+     }
+     menuRelogon();
+     if(connection.isConnected())
+        addRecentConnection(QString(connection.getIPAddressString().c_str())
+              + ":" + QString().setNum(connection.getIPPort()));
+   }
+}
+
+void Knapster::addRecentConnection(const QString &conn)
+{
+  if(conn!="")
+  {
+    if(recentConnection.find(conn) == -1)
+    {
+      if( recentConnection.count() < 5)
+      {
+        recentConnection.insert(0, conn);
+      }
+      else
+      {
+        recentConnection.remove(4);
+        recentConnection.insert(0, conn);
+      }
+    }
+  }
+  prevconnect_menu->clear();
+  for ( int i=0 ; i < (int) recentConnection.count(); i++)
+  {
+    prevconnect_menu->insertItem(recentConnection.at(i));
+  }
+}
+
+
 // slot for the search textedit
 void Knapster::startSearch(int type,const char *text)
 {
@@ -342,6 +401,9 @@ void Knapster::menuProperties()
   searchpanel->setShowSearchPath(newprefs.showpath);
   searchpanel->setMultiSelect(newprefs.multiselect);
 
+  console->setColors(newprefs.normalcol,newprefs.infocol,
+       newprefs.messagecol,newprefs.errorcol);
+
   return;
 }
 // menu slection slot menu logon/off
@@ -356,7 +418,7 @@ void Knapster::menuLogon()
      }
 
      connection.Disconnect();
-     writeConsole(i18n("Disconnected"));
+     writeConsole(i18n("Disconnected"),ExtListBox::Info);
      statusBar()->message(i18n("Not Connected"));
 
      return;
@@ -368,6 +430,11 @@ void Knapster::menuLogon()
 
   searchpanel->clearSearch();
 
+
+  // select the console window
+//  tab->setTabEnabled("console" /*console->name("")*/,false);
+  tab->setTabNum(0);
+
   // write what's happening
   writeConsole("KNapster " VERSION " - John Donoghue, 2000\ndonoghue@chariot.net.au\n");
 
@@ -421,10 +488,10 @@ void Knapster::menuLogon()
       if(!connection.Login(p.username,p.password,p.email,p.speed,p.newuser))
          writeConsole(QString(i18n("Could not logon: ")) + connection.getLastErrorStr());
     }
-    else writeConsole(QString(i18n("Could not connect to best host: ")) + connection.getLastErrorStr());
+    else writeConsole(QString(i18n("Could not connect to best host: ")) + connection.getLastErrorStr(),ExtListBox::Error);
 
   }
-  else writeConsole(QString(i18n("Could not connect to server: ")) + connection.getLastErrorStr() );
+  else writeConsole(QString(i18n("Could not connect to server: ")) + connection.getLastErrorStr(),ExtListBox::Error);
 
   // did we get through all that ok?
   if(connection.isConnected()) {  // YES - we're connected
@@ -432,8 +499,11 @@ void Knapster::menuLogon()
      statusBar()->changeItem(i18n("Connected"),0);
      writeConsole(i18n("Connected to ") + QString(connection.getIPAddressString().c_str()) + "\n");
 
+     addRecentConnection(QString(connection.getIPAddressString().c_str())
+              + ":" + QString().setNum(connection.getIPPort()));
+
      if(connection.getListener()==-1) {
-       writeConsole(i18n("***Warning: ") + QString(i18n("no listener could be created - some downloads will not work\n")));
+       writeConsole(i18n("***Warning: ") + QString(i18n("no listener could be created - some downloads will not work\n")),ExtListBox::Error);
      }
 
      // add the klistener
@@ -456,10 +526,13 @@ void Knapster::menuLogon()
      statusBar()->message(i18n("Not connected"));
   }
 
-
-  // TESTIT
+#ifdef TESTIT
+  sendSharedSongs();
+#else
   songpos=0;
   songnames=librarypanel->getAllSongNames();
+#endif
+
 }
 
 // menu selection slot for menu RElogin
@@ -467,7 +540,7 @@ void Knapster::menuRelogon()
 {
   // can't relogin if already connected
   if(connection.isConnected()) {
-     writeConsole(i18n("Still connected?? - logoff first"));
+     writeConsole(i18n("Still connected?? - logoff first"),ExtListBox::Error);
      return;
   }
   // have we got the host ??
@@ -481,6 +554,9 @@ void Knapster::menuRelogon()
   // clear console but keep the search items since they should still be valid
   menuConsoleClear();
 
+  // select the console window
+  tab->setTabNum(0);
+
   // print whats going on
   writeConsole("KNapster " VERSION " - John Donoghue, 2000\ndonoghue@chariot.net.au\n");
   statusBar()->message(i18n("Trying to relogin..."));
@@ -495,9 +571,9 @@ void Knapster::menuRelogon()
       writeConsole(i18n("logging on..."));
       kapp->processEvents(1000);
       if(!connection.Login(p.username,p.password,p.email,p.speed,p.newuser))
-         writeConsole(QString(i18n("Could not logon: ")) + connection.getLastErrorStr());
+         writeConsole(QString(i18n("Could not logon: ")) + connection.getLastErrorStr(),ExtListBox::Error);
   }
-  else writeConsole(QString(i18n("Could not connect to best host")) + connection.getLastErrorStr());
+  else writeConsole(QString(i18n("Could not connect to best host")) + connection.getLastErrorStr(),ExtListBox::Error);
 
   // did we connect
   if(connection.isConnected()) { // YES - tell the world.
@@ -505,7 +581,7 @@ void Knapster::menuRelogon()
      statusBar()->changeItem(i18n("Connected"),0);
      writeConsole(i18n("Connected to ") + QString(connection.getIPAddressString().c_str()) + "\n");
      if(connection.getListener()==-1) {
-       writeConsole(i18n("** Warning: ") + QString(i18n("no listener could be created - some downloads will not work\n")));
+       writeConsole(i18n("** Warning: ") + QString(i18n("no listener could be created - some downloads will not work\n")),ExtListBox::Error);
      }
 
      listener = new KSocket(connection.getSocket());
@@ -524,6 +600,13 @@ void Knapster::menuRelogon()
   else { // no connection made
      statusBar()->message(i18n("Not connected"));
   }
+
+#ifdef TESTIT
+  sendSharedSongs();
+#else
+  songpos=0;
+  songnames=librarypanel->getAllSongNames();
+#endif
 }
 
 // read socket slot for the napster connection
@@ -533,9 +616,9 @@ void Knapster::napsterRead(KSocket *s)
   SongInfo *tmpinfo;
 
   // read pending block
-  blk=connection.readBlock();
+  blk=connection.readBlock(false);
 
-#ifdef DEBUG_4
+#ifdef DEBUG_5
   if(blk->type!=NAP_ERROR) writeConsole( QString("** read [")+ QString().setNum(blk->type) +
        QString("] size: ") + QString().setNum(blk->size)+ "=" + blk->data );
 #endif
@@ -560,6 +643,17 @@ void Knapster::napsterRead(KSocket *s)
 #endif
        connection.writeBlock(NAP_PING_RESULT,blk->data,blk->size);
        break;
+    case NAP_UPLOAD_REQ_NEW:
+       // someone wants a sonf from us ( they are behind a firewall )
+#ifdef DEBUG_1
+       cerr<<"someone has requested a NEW upload song!! "<<blk->data<<endl<<flush;
+#endif
+       if(blk->size>0) {
+         // parsed the same as a 204 msg
+         tmpinfo=parseDownloadBuffer(blk->data);
+         if(tmpinfo) addUploadItem(tmpinfo);
+       }
+       break;
     case NAP_PING_RESULT:
          processPingResult(blk->data);
        break;
@@ -589,13 +683,13 @@ void Knapster::napsterRead(KSocket *s)
          processChanUserLeft(blk->data);
        break;
     case NAP_CHAN_TOPIC:
-       writeConsole(QString(i18n("topic for ")) + blk->data );
+       writeConsole(QString(i18n("topic for ")) + blk->data ,ExtListBox::Info);
        break;
     case NAP_CHAN_MSG:
          processChanMessage(blk->data);
        break;
     case NAP_JOINCHAN_RESULT: // joined OK??
-       writeConsole(QString(i18n("Joined channel ")) + blk->data);
+       writeConsole(QString(i18n("Joined channel ")) + blk->data,ExtListBox::Info);
        break;
     case NAP_SEARCH_RESULT:
        if(blk->size>0) {
@@ -621,7 +715,7 @@ void Knapster::napsterRead(KSocket *s)
        }
        break;
     case NAP_REMOTEQUEUEFULL:
-       writeConsole(QString(i18n("User remote queue full: ")) + blk->data);
+       writeConsole(QString(i18n("User remote queue full: ")) + blk->data,ExtListBox::Error);
        if(blk->size>0) {
          tmpinfo=parseRemoteQueueBuffer(blk->data);
          if(tmpinfo) delDownloadItem(tmpinfo);
@@ -629,16 +723,16 @@ void Knapster::napsterRead(KSocket *s)
        break;
     case NAP_DOWNLOAD_ERROR:
 // REMOVE from download list???????????
-       writeConsole(QString(i18n("Napster server error downloading ")) + blk->data);
+       writeConsole(QString(i18n("Napster server error downloading ")) + blk->data,ExtListBox::Error);
        break;
     case NAP_SYSTEM_MSG:
-       writeConsole(blk->data);
+       writeConsole(blk->data,ExtListBox::Info);
        break;
     case NAP_BROWSE_ERROR:
-       writeConsole(QString(i18n("Browse error: ")) + blk->data );
+       writeConsole(QString(i18n("Browse error: ")) + blk->data ,ExtListBox::Error);
        break;
     case NAP_ERROR_MSG:
-       writeConsole(QString("** ") + blk->data );
+       writeConsole(QString("** ") + blk->data ,ExtListBox::Error);
        break;
 
     default:
@@ -653,7 +747,7 @@ void Knapster::napsterRead(KSocket *s)
 // close socket slot for the napster connection
 void Knapster::napsterClose(KSocket *s)
 {
-  writeConsole(i18n("Napster connection has been closed"));
+  writeConsole(i18n("Napster connection has been closed"),ExtListBox::Error);
 
   // make sure it was disconnected properly
   connection.Disconnect();
@@ -698,6 +792,55 @@ void Knapster::downloadTerminate(QListViewItem *it)
   }
 }
 
+// slot for downlaod terminate and deletion of (incomplete) file item signal
+void Knapster::downloadTerminateAndDelete(QListViewItem *it)
+{
+
+  if(it) {
+#ifdef DEBUG_1
+    cerr<<"trying to kill "<<it->text(DLV_FILE)<<endl<<flush;
+#endif
+    SongInfo *sg;
+    // find it
+    for(sg=downloadlist.first();sg!=NULL;sg=downloadlist.next()) {
+      if(sg->md5.findRev(it->text(DLV_XTRA))==0) {
+         // found match
+         if(sg->dload) {
+             switch(QMessageBox::warning(this, "Knapster " ,
+						 						QString("Terminate and delete the file:\n") +
+												sg->dload->getLocalName(),
+												QMessageBox::Yes | QMessageBox::Default,
+												QMessageBox::Cancel | QMessageBox::Escape ) ) {
+								case QMessageBox::Yes:	//Yes/Enter pressed
+									 //cancel the download
+									 sg->dload->cancel();
+									 
+									 //now unlink the file
+#ifdef DEBUG_1
+									 cerr << "deleting file: " << sg->dload->getLocalName() << endl;
+#endif
+									 if(!QFile::remove( sg->dload->getLocalName() ) ){
+									 		QMessageBox::critical(this, "Knapster",
+														QString("Unable to delete file: ") +
+														sg->dload->getLocalName()//,
+														//QMessageBox::Ok | QMessageBox::Default
+														);
+									 }
+														
+									 
+									 
+									 break;
+								case QMessageBox::Cancel:	//Cancel/Escape pressed
+									 //Don't do anything
+									 break;
+							}
+         }
+         break;
+      }
+    }
+  }
+}
+
 // slot for uplaod terminate item signal
 void Knapster::uploadTerminate(QListViewItem *it)
 {
@@ -838,10 +981,10 @@ void Knapster::delDownloadItem(SongInfo *tmpinfo)
              <<" because of 620 msg ***************\n"<<flush<<endl;
 #endif
         QString tmpstr;
-//JADE        tmpstr.sprintf(i18n("** Couldn't download %s from %s because their download queue is full\n"), sg->filename, sg->user);
+
         tmpstr = i18n("** Couldn't download ") + sg->filename + i18n(" from ") + sg->user + i18n(" because their download queue is full");
 
-        writeConsole(tmpstr.data());
+        writeConsole(tmpstr.data(),ExtListBox::Error);
 
         downloadpanel->removeDownloadItem(sg);
         if(sg->dload) delete sg->dload;
@@ -855,12 +998,74 @@ void Knapster::delDownloadItem(SongInfo *tmpinfo)
   return;
 }
 
+/*
+ * addUploadItem only occurs when the upload needs to be done by us
+ * ie: they are behind a firewall and we have to do all the hard work.
+ */
+void Knapster::addUploadItem(SongInfo *tmpinfo)
+{
+#ifdef DEBUG_1
+  cout<<"In add NEW upload item------------------------\n"<<endl<<flush;
+#endif
+
+  if(tmpinfo->port==0) { // a firewall-firewall ??
+#ifdef DEBUG_1
+    cerr<<"attempted firewall-firewall uplaod prevented"<<endl<<flush;
+#endif
+    return;
+  }
+  /* startup the u[plaod thread with all the info */
+
+  QString filepath  = tmpinfo->filename;
+
+  // convert the name to a unix name
+  filepath =  toUnixName(filepath);
+
+  // check that this file is an allowed share file
+  if(librarypanel->isSharedSong(filepath)!=true) {
+     writeConsole(
+          QString("Warning someone tried to download unshared song ") + filepath,
+          ExtListBox::Error);
+
+     return;
+  }
+
+  NapsterUpload *uload = new NapsterUpload(
+     tmpinfo->ip, //long ip,
+     tmpinfo->port, //int port,
+     filepath, //const char *filename,
+     tmpinfo->user, //const char *user,
+     tmpinfo->speed, //int speed,
+     NULL //const char *dest
+  );
+  if(!uload) {
+#ifdef DEBUG_1
+     cerr<<"no mem for uload"<<endl<<flush;
+#endif
+     return;
+  }
+  SongInfo *song=new SongInfo(*tmpinfo);
+
+  if(!song) return; // out of memory ???????????????????
+
+  song->md5 = tmpinfo->md5;
+  song->dload=uload;  // save ptr to the download
+
+  uploadlist.append(song);
+  uploadpanel->addUploadItem(song);
+
+  uload->start();
+
+  // notify the server that we have a upload in progress
+  connection.upload_started_signal();
+
+}
 
 // function called on recieval of a download result block
 void Knapster::addDownloadItem(SongInfo *tmpinfo)
 {
 #ifdef DEBUG_1
-  cout<<"In add down load item------------------------\n"<<endl<<flush;
+  cout<<"In add download item------------------------\n"<<endl<<flush;
 #endif
 
   Preferences p=PropertiesDlg::readPrefs();
@@ -868,16 +1073,15 @@ void Knapster::addDownloadItem(SongInfo *tmpinfo)
   if(tmpinfo->port==0) { // download 2 type of download
     if(connection.getListener()==-1) {
        QString tmpstr;
-//JADE       tmpstr.sprintf(i18n("** Can't download %s from %s as there is no listener connection."), tmpinfo->filename, tmpinfo->user);
        tmpstr =i18n("** Can't download ") + tmpinfo->filename + i18n("from") + tmpinfo->user + i18n(" as there is no listener connection.");
 
-       writeConsole(tmpstr.data());
+       writeConsole(tmpstr.data(),ExtListBox::Error);
        return;
      }
      else if(p.port==0) {
        writeConsole(QString(i18n("** Can't download "))
           + tmpinfo->filename
-          + i18n(" since both persons are behind a firewall"));
+          + i18n(" since both persons are behind a firewall"),ExtListBox::Error);
        return;
      }
 
@@ -919,8 +1123,6 @@ void Knapster::addDownloadItem(SongInfo *tmpinfo)
   if(dload) {
 
     QString tmpstr;
-//JADE    tmpstr.sprintf(i18n("Queueing download of %s from %s"), tmpinfo->filename, tmpinfo->user);
-// doesn't like the imbedded %s in the string
     tmpstr =  i18n("Queueing download of ") + tmpinfo->filename + " from " + tmpinfo->user;
     writeConsole(tmpstr.data());
 
@@ -942,8 +1144,11 @@ void Knapster::addDownloadItem(SongInfo *tmpinfo)
    }
    else {
      QString tmpstr;
-//JADE     tmpstr.sprintf(i18n("Couldn't connect to %s to download %s"), tmpinfo->user, tmpinfo->filename);
-     writeConsole(tmpstr.data());
+
+     tmpstr =  i18n("Error: Couldn't create download to start download of ")
+        + tmpinfo->filename + " from " + tmpinfo->user;
+
+     writeConsole(tmpstr.data(),ExtListBox::Error);
    }
    return;
 }
@@ -997,7 +1202,7 @@ void Knapster::updateDownloadList()
       else if(sg->status==NapsterDownload::DL_KILLED) {
         if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
-        writeConsole(i18n("User terminated download of ") + sg->filename );
+        writeConsole(i18n("User terminated download of ") + sg->filename ,ExtListBox::Error);
 
         // delete
         downloadpanel->removeDownloadItem(sg);
@@ -1015,7 +1220,7 @@ void Knapster::updateDownloadList()
 //JADE        tmpstr.sprintf(i18n("Couldn't connect to %s to start download of %s"), sg->user, sg->filename);
         tmpstr = i18n("Couldn't connect to ") + sg->user + i18n(" to start download of ") + sg->filename;
 
-        writeConsole(tmpstr.data());
+        writeConsole(tmpstr.data(),ExtListBox::Error);
 
         // delete
         downloadpanel->removeDownloadItem(sg);
@@ -1033,7 +1238,7 @@ void Knapster::updateDownloadList()
 //JADE        tmpstr.sprintf(i18n("Couldn't open local file to save %s from %s"), sg->filename, sg->user);
         tmpstr = i18n("Couldn't open local file to save ") + sg->filename + i18n(" from ") + sg->user;
 
-        writeConsole(tmpstr.data());
+        writeConsole(tmpstr.data(),ExtListBox::Error);
 
         // delete
         downloadpanel->removeDownloadItem(sg);
@@ -1044,18 +1249,33 @@ void Knapster::updateDownloadList()
         connection.download_finished_signal();
 
       }
+      else if(sg->status==NapsterDownload::DL_TIMEOUT) {
+        if((PropertiesDlg::readPrefs()).beep) kapp->beep();
+        sg->ignore=true;
+
+        QString tmpstr;
+        tmpstr = i18n("Time out occured trying to download ") + sg->filename + i18n(" from ") + sg->user;
+
+        writeConsole(tmpstr.data(),ExtListBox::Error);
+
+        // delete
+        downloadpanel->removeDownloadItem(sg);
+        delete sg->dload;
+        downloadlist.remove(sg);
+
+        // tell server we are finished downloading a file
+        connection.download_finished_signal();
+      }
       else if(sg->status<0) { // one of the other error conditions
         if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
         QString tmpstr;
-// JADE        tmpstr.sprintf(i18n("Error occured during download of %s from %s"), sg->filename, sg->user);
         tmpstr = i18n("Error occured during download of ") + sg->filename + i18n(" from ") + sg->user;
 
-        writeConsole(tmpstr.data());
-//JADE        tmpstr.sprintf(i18n("** read %d of %d bytes."), sg->read, sg->size);
+        writeConsole(tmpstr.data(),ExtListBox::Error);
         tmpstr = i18n("** read ") + QString().setNum(sg->read) +
                 QString(" / ") + QString().setNum(sg->size) + i18n(" bytes");
-        writeConsole(tmpstr.data());
+        writeConsole(tmpstr.data(),ExtListBox::Error);
 
         downloadpanel->removeDownloadItem(sg);
         delete sg->dload;
@@ -1092,7 +1312,14 @@ void Knapster::updateUploadList()
 
   // update uploadlist
   SongInfo *sg;
+
   for(sg=uploadlist.first();sg!=NULL;sg=uploadlist.next()) {
+#ifdef DEBUG_1
+    cerr<<"update item " << sg->filename<<endl<<flush;
+    if(sg->dload) cerr<<"has dload info";
+    else cerr<<"no dload info";
+    cerr<<endl<<flush;
+#endif
     if(sg->dload && !sg->ignore) {
       sg->dload->getInfo(&sg->status,&sg->read,&sg->size,&sg->bps);
 
@@ -1116,7 +1343,7 @@ void Knapster::updateUploadList()
       else if(sg->status==NapsterUpload::DL_KILLED) {
         //if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
-        writeConsole(i18n("User terminated upload of ") + sg->filename );
+        writeConsole(i18n("User terminated upload of ") + sg->filename ,ExtListBox::Error);
 
         // delete
         uploadpanel->removeUploadItem(sg);
@@ -1125,15 +1352,13 @@ void Knapster::updateUploadList()
 
         // tell server we are finished uploading a file
         connection.upload_finished_signal();
-
       }
       else if(sg->status<0) { // one of the other error conditions
 //        if((PropertiesDlg::readPrefs()).beep) kapp->beep();
         sg->ignore=true;
         QString tmpstr;
-//JADE        tmpstr.sprintf(i18n("Error occured during upload of %s from %s"),sg->filename, sg->user);
         tmpstr = i18n("Error occured during upload ") + sg->filename + i18n(" from ") + sg->user;
-        writeConsole(tmpstr.data());
+        writeConsole(tmpstr.data(),ExtListBox::Error);
 
         uploadpanel->removeUploadItem(sg);
         delete sg->dload;
@@ -1153,7 +1378,6 @@ bool Knapster::startDownload(SongInfo *song)
 {
   if(song->port!=0) {  // dload 1
     QString tmpstr;
-//JADE    tmpstr.sprintf(i18n("Starting download of %s from %s") ,song->filename, song->user);
     tmpstr = i18n("Starting download of ") + song->filename + i18n(" from ") + song->user;
     writeConsole(tmpstr.data());
 
@@ -1166,10 +1390,11 @@ bool Knapster::startDownload(SongInfo *song)
 
     connection.writeBlock(NAP_DOWNLOAD_REQ_NEW, s,s.length());  // ask for new type dload
 #ifdef DEBUG_1
-    cerr<<"XXXX sending new commands of "<<s<<endl<<flush;
+    cerr<<"XXXX sending new commands [500] of "<<s<<endl<<flush;
 #endif
     QString tmpstr;
-    tmpstr = i18n("Waiting for ") + song->filename + i18n(" to connect...");
+    tmpstr = i18n("Waiting for ") + song->user + i18n(" to connect...");
+    writeConsole(tmpstr.data());
 
     // tell the world that we have started initialising it
     song->dload->setInit();
