@@ -26,13 +26,18 @@
 #include "napsterconnection.h"
 #include "songinfo.h"
 #include <qlist.h>
+#include <qmessagebox.h>
+#include <qfile.h>
+#include <qstrlist.h>
 
 #include <qdatetime.h>
 
+#include "extlistbox.h"
+
 #include "../config.h"   // for version etc
 
 
-// class to hold info about panding pings that have been sent to the server
+// class to hold info about pending pings that have been sent to the server
 class PingItem
 {
 public:
@@ -59,6 +64,10 @@ class ConsolePanel;
 class DownloadPanel;
 class LibraryPanel;
 class UploadPanel;
+
+//class KTabCtl;
+class ExtTab;
+
 //class KHTMLView;
 
 class Knapster : public KTMainWindow
@@ -72,6 +81,9 @@ class Knapster : public KTMainWindow
     void menuRelogon();
     void menuProperties();
 
+    // open recent
+    void menuOpenRecent(int);
+
     // on app closedown
     void closeDown();
 
@@ -88,6 +100,7 @@ class Knapster : public KTMainWindow
 
     // download slots
     void downloadTerminate(QListViewItem *);
+    void downloadTerminateAndDelete(QListViewItem *);
     void playsong_dl(const char *);
 
     // upload slots
@@ -107,6 +120,7 @@ class Knapster : public KTMainWindow
   public slots:
     // load the mp3 paths from the prefs
     void loadMP3LibraryPaths();
+
   private:
     NapsterConnection connection;
 
@@ -116,6 +130,13 @@ class Knapster : public KTMainWindow
     // the external mp3 player process
     KProcess player;
 
+    // the open previous connection popup
+    QPopupMenu *prevconnect_menu;
+    QStrList recentConnection;
+
+    // the tab widget
+    ExtTab *tab;
+
     // tab1
     ConsolePanel *console;
 
@@ -147,17 +168,22 @@ class Knapster : public KTMainWindow
     virtual ~Knapster();
 
   private:
+    void addRecentConnection(const QString &conn);
 
     void setupMenus();
     void setupTabs();
 
-    void writeConsole(char *s);
-    void writeConsole(QString s);
+    void writeConsole(char *s,ExtListBox::LineType type=ExtListBox::None);
+    void writeConsole(QString s,ExtListBox::LineType type=ExtListBox::None);
 
     void addSearchItem(SongInfo *tmpinfo);
     void addDownloadItem(SongInfo *tmpinfo);
     void delDownloadItem(SongInfo *tmpinfo);
 
+    // only usedfor when other person is behind a firewall and we
+    // have to connect to them
+    void addUploadItem(SongInfo *tmpinfo);
+
     void showServerStats(NAPBLOCKPTR);
 
     QString convertSecondsToDurationString(long s);
@@ -193,4 +219,4 @@ class Knapster : public KTMainWindow
     void sendSharedSongs();
 };
 
-#endif
\ No newline at end of file
+#endif
