@@ -77,8 +77,14 @@ bool Knapster::checkForConnections()
      return false;
   }
   // ************************************
-  send(sock, "\n", 1, 0);         // ??????????????????????????
-  // ************************************
+  if(send(sock, "1", 1, 0)<=0) {         // ??????***** WAS \n
+#ifdef DEBUG_1
+     cerr<<"error sending initial '1'\n"<<flush;
+#endif
+     close(sock);
+     return false;
+  }
+
   char buffer[8];
   int n;
 
@@ -103,9 +109,17 @@ bool Knapster::checkForConnections()
 #endif
     return processUploadConnection(sock);
   }
-
-  // otherwise, assume a download
-  return processDownloadConnection(sock);
+  else if(strncmp("SEND",buffer,4)==0) {
+#ifdef DEBUG_1
+    cerr<<"someone wants to send a file to us in check func!!!!!! "<<endl<<flush;
+#endif
+    // otherwise, assume a download
+    return processDownloadConnection(sock);
+  }
+#ifdef DEBUG_1
+    cerr<<"unknown action gotton:"<<buffer<<endl<<flush;
+#endif
+  return false;
 }
 
 bool Knapster::processDownloadConnection(int sock)
@@ -119,7 +133,7 @@ bool Knapster::processDownloadConnection(int sock)
   long size=0;
 
   n=recv(sock,buffer,4096,0);
-  if(n==-1) {
+  if(n<=-1) {
 #ifdef DEBUG_1
      cerr<<"error reading new header\n"<<flush;
 #endif
@@ -144,18 +158,26 @@ bool Knapster::processDownloadConnection(int sock)
 
   str=strchr(str,' '); // get end of uname
   if(str) {
-    *str='\0';
-    str++;
+    if(*str!='\0') {
+      *str='\0';
+      str++;
+    }
     str=strchr(str,'\"');    // get to start of filename
   }
   if(str) {
-     str++;
+     if(*str!='\0')
+     {
+       *str='\0';
+       str++;
+     }
      filename=str;
      str=strchr(str,'\"'); // get to the end of filename
   }
   if(str) {
-    *str='\0';
-    str+=2; // get to the zize
+    if(*str!='\0') {
+      *str='\0';
+      str+=2; // get to the size
+     }
      size=atol(str);
   }
 
@@ -205,7 +227,7 @@ bool Knapster::processUploadConnection(int sock)
   long startfrom=0;
 
   n=recv(sock,buffer,4096,0);
-  if(n==-1) {
+  if(n<=-1) {
 #ifdef DEBUG_1
      cerr<<"error reading new ul header\n"<<flush;
 #endif
@@ -260,8 +282,6 @@ bool Knapster::processUploadConnection(int sock)
   QString filepath =  filename;
 
   filepath =  toUnixName(filepath);
-//SearchPanel::makeFullFilePath(
-//         (PropertiesDlg::readPrefs()).uploaddir,filename);
 
 #ifdef DEBUG_1
      cerr<<"to send file "<<filepath<<endl<<flush;
@@ -271,15 +291,14 @@ bool Knapster::processUploadConnection(int sock)
   // check that this file is an allowed share file
   if(librarypanel->isSharedSong(filepath)!=true) {
      writeConsole(
-          QString("Warning someone tried to download unshared song ")
-          + filepath);
+          QString("Warning someone tried to download unshared song ") + filepath,
+            ExtListBox::Error);
 
      close(sock);
      return false;
   }
 
 
-/////////// create thread here!!!!!!!!!!!!!1
   NapsterUpload *uload = new NapsterUpload(
      0, //long ip,
      0, //int port,
@@ -311,16 +330,19 @@ bool Knapster::processUploadConnection(int sock)
   // notify the server that we have a upload in progress
   connection.upload_started_signal();
 
-//  close(sock);
   return true;
 }
 
 void Knapster::sendSharedSongs()
 {
+// to do -> this can be somewhat slow doing this for every song
+// speed up by caching parts or more multitasking ??
+// probally the MD5 connection will be really bad
+
   int i;
   if(songpos>=0 && connection.isConnected()) {
-    for(i=0;songpos<songnames.count() && i<5; songpos++, i++) {
-//      SongInfo *song = SongInfo::loadSongInfo(songnames.at(songpos),true);
+    for(i=0;songpos<(int)songnames.count() && i<2; songpos++, i++) {
+
       SongInfo *song = librarypanel->findSongInfo((const char *)songnames.at(songpos),true);
 
       if(song) {
@@ -329,7 +351,7 @@ void Knapster::sendSharedSongs()
            connection.share(song);
       }
     }
-    if(songpos>=songnames.count()) songpos=-1;
+    if((unsigned int)songpos>=songnames.count()) songpos=-1;
   }
 
   return;
