@@ -18,7 +18,7 @@
 #include "librarypanel.h"
 #include "support_funcs.h"
 
-#include <qlistview.h>
+#include <extlistview.h>
 #include <qlayout.h>
 #include <qpopupmenu.h>
 #include <qlabel.h>
@@ -31,7 +31,6 @@
 
 #include <stdlib.h>
 
-//#include "searchpanel.h"
 #include "songinfo.h"
 
 #include <iostream.h>
@@ -39,6 +38,8 @@
 #include <qdir.h>
 #include <qfile.h>
 
+#include "mp3.xpm"
+
 class LibraryItem : public QListViewItem
 {
 public:
@@ -98,7 +99,7 @@ LibraryPanel::LibraryPanel(QWidget *parent, const char *name )
   connect(rescanbutton,SIGNAL(clicked()),this,SLOT(buttonRescan()));
   grid->addWidget(rescanbutton,0,1);
 
-  sharedlistview=new QListView(this);
+  sharedlistview=new ExtListView(this,"libraryview");
   sharedlistview->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
   grid->addMultiCellWidget(sharedlistview,1,1,0,1);
 
@@ -114,6 +115,8 @@ LibraryPanel::LibraryPanel(QWidget *parent, const char *name )
   sharedlistview->addColumn(i18n("shared"),80);
   sharedlistview->setColumnWidthMode(4,QListView::Manual);
 
+  sharedlistview->loadWidths();
+
   // create the popup menu for the downloadlist view
   sharedpopupmenu=new QPopupMenu();
   if(sharedpopupmenu) {
@@ -121,12 +124,11 @@ LibraryPanel::LibraryPanel(QWidget *parent, const char *name )
   }
   connect(sharedlistview,SIGNAL(rightButtonPressed( QListViewItem *, const QPoint &, int )),
        this,SLOT(popupMenu( QListViewItem *, const QPoint &, int )));
-
 }
 
 LibraryPanel::~LibraryPanel()
 {
-// if sharedpopupmenu
+
 }
 
 void LibraryPanel::popupPlay()
@@ -180,6 +182,8 @@ void LibraryPanel::addItem(const QString &name,int bitrate,int freq,long size,bo
         QString().setNum(size),
         shared == true ? "Yes" : "No",
         name);
+  // set the pixmap just to add a bit of 'color'
+  if(i) i->setPixmap(0,QPixmap((const char **)mp3_xpm));
 
   if(shared) sharedcount++;
 
@@ -220,7 +224,7 @@ SongInfo *LibraryPanel::findSongInfo(const char *fname, bool getall)
          return &asong;
        }
        else { // load it in
-          SongInfo *nsong = SongInfo::loadSongInfo(fname,true);
+          SongInfo *nsong = SongInfo::loadSongInfo(fname,getall);
           if(nsong) {
              if(strcmp(it->text(4),"Yes")==0) nsong->shared=true;
              else nsong->shared=false;
@@ -268,7 +272,8 @@ int LibraryPanel::addDir(const char *name,bool shared,int depth)
     else {
       si=findSongInfo(fi->absFilePath());
       if(si==NULL) {
-        si=SongInfo::loadSongInfo(fi->absFilePath());
+// LOADING MD5 as well!!
+        si=SongInfo::loadSongInfo(fi->absFilePath(),false);
         if(si) {
           addItem(fi->absFilePath(),si->bitrate,si->freq,si->size,shared);
           cnt++;
