@@ -20,7 +20,7 @@
 
 #include <qwidget.h>
 
-class QListView;
+class ExtListView;
 class QListViewItem;
 class QPoint;
 class QLabel;
@@ -69,7 +69,7 @@ public:
 private:
   void addItem(const QString &name,int bitrate,int freq,long size,bool shared);
 private:
-  QListView *sharedlistview;
+  ExtListView *sharedlistview;
   QPopupMenu *sharedpopupmenu;
   QLabel *stats;
 
