@@ -34,6 +34,14 @@
 
 #include <iostream.h>
 
+// to use with knapster, needs some kde event processing
+// done when waiting
+//#define KDE_INTERACTION
+
+
+#ifdef KDE_INTERACTION
+ #include <kapp.h>
+#endif
 
 // some machines dont seem to know this constant
 #ifndef INADDR_NONE
@@ -66,7 +74,8 @@ static char * int2str(int val)
 
 const char *NapsterConnection::errorstr[]=
 {
-     "Ok","Bad port number","Bad IP number","Cannot connect to host",
+     "Ok","Timeout","Bad port number","Bad IP number",
+     "Cannot connect to host",
      "Read error","Write error",
      "Server is busy","Could not connect to server to get best host",
      "Bad data received","Trying to send bad data",
@@ -145,6 +154,10 @@ bool NapsterConnection::Connect(int port)
     return false;
   }
 
+#ifdef KDE_INTERACTION
+  kapp->processEvents(1000);
+#endif
+
   if(connect(_napster,(sockaddr *)&_sockaddr,sizeof(struct sockaddr))<0) {
     close(_napster);
     _napster=-1;
@@ -222,6 +235,10 @@ bool NapsterConnection::getBestHost(const char *server)
   _sockaddr.sin_family = AF_INET;
   _sockaddr.sin_port = htons(SERVER_PORT);
 
+#ifdef KDE_INTERACTION
+  kapp->processEvents(1000);
+#endif
+
   if(connect(sock,(sockaddr *)&_sockaddr,sizeof(struct sockaddr))<0) {
       // no coonect
 #ifdef DEBUG_1
@@ -233,8 +250,36 @@ bool NapsterConnection::getBestHost(const char *server)
 #ifdef DEBUG_1
   cout<<"connected to "<<getIPAddressString()<<endl<<flush;
 #endif
+
+#ifdef KDE_INTERACTION
+  kapp->processEvents(1000);
+#endif
+
   // get the best host info
   int sz;
+  // TODO add timeout if can't connect
+  fd_set fdsr;
+  struct timeval tm;
+
+  tm.tv_sec=0;
+  tm.tv_usec=500;
+
+  FD_ZERO(&fdsr);
+  FD_SET(sock,&fdsr);
+  while((sz = select(sock+1,&fdsr,NULL,NULL,&tm))==0)
+  {
+#ifdef KDE_INTERACTION
+    kapp->processEvents(1000);
+#endif
+
+    tm.tv_sec=0;
+    tm.tv_usec=500;
+
+    FD_ZERO(&fdsr);
+    FD_SET(sock,&fdsr);
+
+  }
+
   if((sz=recv(sock,_buffer,256,0))<=0) {
      close(sock);
 #ifdef DEBUG_1
@@ -250,8 +295,6 @@ bool NapsterConnection::getBestHost(const char *server)
 #ifdef DEBUG_1
   cout<<"read data for host was '"<<_buffer<<"'\n";
 #endif
-  // get the address to connect to ( the best host )
-  char *ip, *p;
 
   if(strncmp(_buffer,"busy",4)==0 || strncmp(_buffer,"wait",4)==0)
   {
@@ -264,8 +307,24 @@ bool NapsterConnection::getBestHost(const char *server)
 #ifdef DEBUG_1
   cerr<<"retrieved server string of: "<<_buffer<<endl<<flush;
 #endif
-  ip = _buffer;
-  p = strchr(_buffer,':');
+  if(!parseBestHostString(_buffer)) return false;
+
+
+
+  return true;
+}
+
+bool NapsterConnection::parseBestHostString(char *str)
+{
+  // get the address to connect to ( the best host )
+  char *ip, *p;
+
+  _havehost=false;
+
+  if(str==NULL) return false;
+
+  ip = str;
+  p = strchr(str,':');
   if(p==NULL) {
 #ifdef DEBUG_1
     cout<<"best host info invalid\n"<<flush;
@@ -287,6 +346,10 @@ bool NapsterConnection::getBestHost(const char *server)
   _sockaddr.sin_family = AF_INET;
   _sockaddr.sin_port = htons(atoi(p));
 
+#ifdef DEBUG_1
+  cerr<<"*** port is at "<<atoi(p)<<endl;
+#endif
+
   _havehost=true;
 
   return true;
@@ -434,7 +497,8 @@ string NapsterConnection::getIPAddressString() const
 
 int NapsterConnection::getIPPort() const
 {
-  return ntohl(_sockaddr.sin_port);
+  return ntohs(_sockaddr.sin_port);
+  // _sockaddr.sin_port = htons
 }
 
 
@@ -444,6 +508,10 @@ int NapsterConnection::readComm(char *xbuffer,int size)
 {
   int s=0;
 
+#ifdef KDE_INTERACTION
+  kapp->processEvents(1000);
+#endif
+
   _lasterror=NAP_OK;
 
   if(_napster==-1) {
@@ -463,6 +531,10 @@ int NapsterConnection::writeComm(const char *astring,int size)
 
   _lasterror=NAP_OK;
 
+#ifdef KDE_INTERACTION
+  kapp->processEvents(1000);
+#endif
+
   if(_napster==-1) {
     _lasterror=NAP_NO_CONNECT;
 
@@ -472,7 +544,7 @@ int NapsterConnection::writeComm(const char *astring,int size)
   return s;
 }
 
-NAPBLOCKPTR NapsterConnection::readBlock()
+NAPBLOCKPTR NapsterConnection::readBlock(bool waitfordata)
 {
   int s;
   NAPBLOCKPTR ptr;
@@ -487,7 +559,43 @@ NAPBLOCKPTR NapsterConnection::readBlock()
 
       return ptr;
   }
+// --- test that reads will get valid data
 
+  // TODO - force it to wait for data if waitfordata is true
+
+
+  if(!waitfordata)
+  {
+    s = recv(_napster,_buffer,2048,MSG_PEEK);
+    if(s<4)
+    {
+       /* not even the start of the header yet */
+        ptr->size=0;
+        ptr->type=NAP_ERROR;
+
+       _lasterror = NAP_NO_READ;
+       return ptr;
+    }
+    ptr->size=NAP_TO_SHORT(ptr->size); // make sure its in the right endian
+
+    if(ptr->size<2048)
+    {
+//       s = ptr->size;
+//       if(recv(_napster,_buffer,4+s,MSG_PEEK)<(4+s))
+       if((ptr->size + 4) > s)
+       {
+         // not enough to read yet
+
+         ptr->size=0;
+         ptr->type=NAP_ERROR;
+
+         _lasterror = NAP_NO_READ;
+         return ptr;
+       }
+    }
+  }
+
+//--------------
   if((s = readComm(_buffer,4))<=0) { // error or no data
       _lasterror=NAP_NO_READ;
 #ifdef DEBUG_1
@@ -828,7 +936,7 @@ bool NapsterConnection::share(const SongInfo *s)
 //  str=str.stripWhiteSpace();
 
 #ifdef DEBUG_1
-  cerr<<"sending: "<<str<<endl<<flush;
+  cerr<<"sending shared: "<<str<<endl<<flush;
 #endif
 
   return writeBlock(NAP_ADDTOSONGLIST_REQ,str,str.length())!=-1;
