@@ -125,7 +125,7 @@
 #define NAP_CHAN_TOPIC 410 // topik data??
 
 #define NAP_DOWNLOAD_REQ_NEW 500
-//#define NAP_DOWNLOAD_NEW_RESULT 501
+#define NAP_UPLOAD_REQ_NEW 501    // some one has requested a song from us
 
 #define NAP_WHOIS_REQ      603
 #define NAP_WHOIS_RESULT   604
@@ -171,7 +171,8 @@ class NapsterConnection
 {
 public:
   typedef enum {
-         NAP_OK=0,NAP_BAD_PORT,NAP_BAD_IP,NAP_NO_CONNECT,
+         NAP_OK=0,NAP_TIMEOUT,
+         NAP_BAD_PORT,NAP_BAD_IP,NAP_NO_CONNECT,
          NAP_NO_READ,NAP_NO_WRITE,
          NAP_SERVER_BUSY,NAP_NOSERVER_CONNECT,
          NAP_BAD_RECV_DATA,NAP_BAD_SEND_DATA,NAP_NO_LOGIN,
@@ -187,6 +188,7 @@ public:
        int speed=0,int port=6699,bool new_user=false);
 
   bool getBestHost(const char *server=SERVER_ADDR);
+  bool parseBestHostString(char *str); // set besthost from a hostip:port string
   bool Connect(int port=6699); // assumes getBestHost was called
   bool Login(const char *username,const char *password,
         const char *email,int speed=0,bool new_user=false);
@@ -213,7 +215,7 @@ public:
        const char *user,int speed,const char *dest);
 
   // r/w functions
-  NAPBLOCKPTR readBlock();
+  NAPBLOCKPTR readBlock(bool waitfordata=true);
   int writeBlock(int type,const char *data,int size);
 
   const char *getBuffer();
