@@ -38,6 +38,12 @@
 #include <stdlib.h>
 #include <iostream.h>
 
+static void sigpipe_handler(int)
+{
+  cerr<<"dload sigpipe caught!!\n"<<flush;
+  return;
+}
+
 NapsterDownload::NapsterDownload(long ip,int port,const char *filename,const char *user,
          int speed,const char *dest)
 : NapsterTransfer(ip,port,filename,user,speed,dest)
@@ -58,10 +64,13 @@ NapsterDownload::NapsterDownload(long ip,int port,const char *filename,const cha
 }
 bool NapsterDownload::init()
 {
+  fd_set fdsr;
+  struct timeval tm;
+  int timeout = 0;
+
   if(_terminate) return true;
 
   int l;
-//  long size;
 
   if(_listener==-1) {    // old type download
 
@@ -80,8 +89,39 @@ bool NapsterDownload::init()
        return false;
      }
      // get rid of that stupid byte that is there
+     // NOTE it may hang here if we never get any data!!!!
+     // better fix this at some stage
      char c;
-     recv(_sock,&c,1,0);
+
+    do {
+      if(_terminate) return false; // got a terminate
+
+      FD_ZERO(&fdsr);
+      FD_SET(_sock,&fdsr);
+
+      tm.tv_sec=1;
+      tm.tv_usec=0;
+
+      timeout++;
+
+      if(_timeoutval>0 && timeout>=60*_timeoutval)
+      {
+        // no data has been read for _timeoutval mins for the header
+#ifdef DEBUG_1
+         cerr<<"init timeout occured "<<endl<<flush;
+#endif
+        down();
+           _status=DL_TIMEOUT;
+        up();
+
+        return false;
+      }
+    }
+    while(select(_sock+1,&fdsr,NULL,NULL,&tm)<=0);
+    // check if data or a terminate
+
+
+    recv(_sock,&c,1,0);
 
      // calc resume pos
   down();
@@ -180,7 +220,7 @@ bool NapsterDownload::header_new()
   send(_sock,s,s.length(),0); // send start pos
 
   down();
-    _readsize=startfrom;  // ???
+    _readsize=startfrom;  // how much has already been read
 
     time(&_starttime); // set the start time
 
@@ -195,6 +235,7 @@ bool NapsterDownload::header()
   int n;
   fd_set fdsr;
   struct timeval tm;
+  int timeout = 0;
 
   // getting the header data still
   char c;
@@ -210,6 +251,21 @@ bool NapsterDownload::header()
 
     tm.tv_sec=1;
     tm.tv_usec=0;
+
+    timeout++;
+
+    if(_timeoutval>0 && timeout>=60*_timeoutval)
+    {
+      // no data has been read for _timeoutval mins for the header
+#ifdef DEBUG_1
+         cerr<<"timeout occured "<<endl<<flush;
+#endif
+        down();
+           _status=DL_TIMEOUT;
+        up();
+
+        return false;
+    }
   }
   while(select(_sock+1,&fdsr,NULL,NULL,&tm)<=0); // check if data or a terminate
 
@@ -254,6 +310,23 @@ bool NapsterDownload::header()
 #endif
       // get the size from the header
       tmp=_buffer;
+
+
+      if(_header_pos==0)
+      {
+         // we got data straight away that isn't the filesize
+         _buffer[0]=c;
+         _header_pos = recv(_sock,&_buffer[1],100,0);
+         if(_header_pos<0) {
+#ifdef DEBUG_1
+           cerr<<"read error in download error reason code\n"<<flush;
+#endif
+           return false;
+         }
+         _buffer[_header_pos + 1] = '\0';
+#ifdef DEBUG_1
+         cerr<<"got error reason: "<<_buffer<<endl<<flush;
+#endif
 //--------------------------------------------
 //       if(strstr(tmp,"INVALID")==NULL) {
 //           sendMsg(DL_ERROR);
@@ -263,6 +336,9 @@ bool NapsterDownload::header()
 // TODO : other errors?????????????????????
 //--------------------------------------------
 
+         return false;
+      }
+
       // open the file
       setDownloadName(_destname,true); // also truncate the file
       if(_file==-1) {
@@ -276,14 +352,9 @@ bool NapsterDownload::header()
       }
 
       if(_file!=-1 && _readsize!=0) { // we have stuff in the file -> append
-//      struct stat statbuff;
-//      if(fstat(_file,&statbuff)==0) {
-//        startfrom=statbuff.st_size;
         lseek(_file,_readsize,SEEK_SET); // go to the end
-//      }
       }
 
-
       // this byte is data -> send there
       write(_file,&c,1); // the first byte
 
@@ -305,6 +376,7 @@ bool NapsterDownload::header()
     if(c=='\0') _header_pos=-1; // ignore the restb of the header??
 
     // if we've got something 'INVALID' or 'NOT' -> an error -> no download will happen
+
   }
 
   return true;
@@ -312,7 +384,7 @@ bool NapsterDownload::header()
 bool NapsterDownload::data()
 {
    int n;
-
+  int timeout=0;
   fd_set fdsr;
   struct timeval tm;
 
@@ -324,6 +396,22 @@ bool NapsterDownload::data()
 
     tm.tv_sec=1;
     tm.tv_usec=0;
+
+    timeout++;
+
+    if(_timeoutval>0 && timeout>=60*_timeoutval)
+    {
+      // no data has been read for _timeoutval mins for the header
+#ifdef DEBUG_1
+         cerr<<"data timeout occured "<<endl<<flush;
+#endif
+        down();
+           _status=DL_TIMEOUT;
+        up();
+
+        return false;
+    }
+
   }
   while(select(_sock+1,&fdsr,NULL,NULL,&tm)<=0); // check if data or a terminate
 
@@ -374,7 +462,7 @@ bool NapsterDownload::setDownloadName(const char *path,bool truncate)
 bool NapsterDownload::start(int _listen,long sz)
 {
   // set that we are initialising
-   _status=DL_INIT;
+  _status=DL_INIT;
 
   // create the thread and start us up
   _listener=_listen;
@@ -385,33 +473,24 @@ bool NapsterDownload::start(int _listen,long sz)
 #ifdef DEBUG_1
   cerr<<"$$$$$$$$$$$$$$$ created thread for "<<_filename<<endl<<flush;
 #endif
-  // sleep(1)
 
   pthread_create(&_id,NULL,thread_task,(void *)this);
+  pthread_detach(_id);
 
   return true;
 }
-/*
-bool NapsterDownload::cancel()
-{
-  down();
-    if(_id) {
-     _terminate=true;
-     _id=0;
 
-    }
-    // in the case of no thread started yet
-    if(_status==DL_QUEUED) _status=DL_KILLED;
-  up();
-  return true;
-}
-*/
 void *NapsterDownload::thread_task(NapsterDownload *dl)
 {
 #ifdef DEBUG_1
   cerr<<"starting download thread\n"<<flush;
 #endif
 
+//  signal(SIGPIPE,SIG_IGN);
+  signal(SIGPIPE,sigpipe_handler);
+
+
+
   if(dl) {
      dl->down();
        dl->_status=DL_INIT;
@@ -420,7 +499,7 @@ void *NapsterDownload::thread_task(NapsterDownload *dl)
   if(!dl || !dl->init()) {
     if(dl) {
         dl->down();
-          dl->_status=DL_NOCONNECT;
+          if(dl->_status!=DL_TIMEOUT) dl->_status=DL_NOCONNECT;
         dl->up();
     }
 #ifdef DEBUG_1
@@ -429,22 +508,20 @@ void *NapsterDownload::thread_task(NapsterDownload *dl)
     return NULL;
   }
 
+  // while we can - process the download - until user terminate
+  // or no read
   while(!dl->_terminate && dl->processDownload()) { }
 
   dl->down();
     if(dl->_terminate) dl->_status=DL_KILLED;
-    else if(dl->_status==DL_NOLOCALFILE) {  } // error has been set already
+    else if(dl->_status==DL_NOLOCALFILE ||
+            dl->_status==DL_TIMEOUT) {  } // error has been set already
     else if (dl->_readsize>=dl->_totalsize) dl->_status=DL_FINISHED;
-    else  dl->_status=DL_ERROR;    // only partial download????
+    else  dl->_status=DL_ERROR;           // only partial download????
   dl->up();
 #ifdef DEBUG_1
   cerr<<"finished download thead\n"<<flush;
 #endif
 
-//******************
-// done in delete
-//  close(_msgsock);
-// _msgsock=-1;
-
   return NULL;
-}
\ No newline at end of file
+}
