@@ -26,6 +26,7 @@
 #include <qpushbutton.h>
 #include <qfiledialog.h>
 #include <kapp.h>
+#include <kcolorbtn.h>
 
 #ifdef KDE2
 #include <kconfig.h>
@@ -102,11 +103,6 @@ void PropertiesDlg::setupTabs()
   email->setMaxLength(46);
   grid->addMultiCellWidget(email,2,2,1,2);
 
-  // retry connect until succesfull
-  // toggle ????????
-
-//  QSize sz(maxw_sz,username->sizeHint().height());
-
   l1->setMaximumWidth(maxw_sz);
   l2->setMaximumWidth(maxw_sz);
   l3->setMaximumWidth(maxw_sz);
@@ -156,13 +152,6 @@ void PropertiesDlg::setupTabs()
   speed->insertItem(i18n("T3+"));
   grid->addWidget(speed,2,1);
 
-//  int w1 = l1->sizeHint().width();
-//  int w5 = l5->sizeHint().width();
-//  int w4 = l4->sizeHint().width();
-//  int width = (w1 > w5) ? w1 : w5;
-//  width = (width > w4) ? width : w4;
-//  sz.setWidth(width);
-//  sz.setHeight(speed->sizeHint().height());
   QSize sz(maxw_sz,speed->sizeHint().height());
 
   port->setMaximumSize(sz);
@@ -205,23 +194,25 @@ void PropertiesDlg::setupTabs()
   maxdownloads->setMaxLength(3);
   grid->addWidget(maxdownloads,1,1);
 
+  l3=new QLabel(i18n("download timeout (mins) "),frame);
+  grid->addWidget(l3,2,0);
+  maxw_sz =  maxw_sz > l3->sizeHint().width() ? maxw_sz : l3->sizeHint().width();
+
+  downloadtimeout = new QLineEdit(frame, "downloadtimeout" );
+  downloadtimeout->setMaxLength(1);
+  grid->addWidget(downloadtimeout,2,1);
+
   beep= new QCheckBox(i18n("Beep on download finish"),frame,"dloadfinish");
-  grid->addMultiCellWidget(beep,2,2,0,3);
+  grid->addMultiCellWidget(beep,3,3,0,3);
   beep->setMaximumHeight(beep->sizeHint().height());
 
   l4=new QLabel(i18n("Max upload connections "),frame);
-  grid->addWidget(l4,3,0);
+  grid->addWidget(l4,4,0);
   maxw_sz =  maxw_sz > l4->sizeHint().width() ? maxw_sz : l4->sizeHint().width();
 
   maxuploads = new QLineEdit(frame, "uploads" );
   maxuploads->setMaxLength(3); // up to 999 should be enough ???? comments anyone ??????
-  grid->addWidget(maxuploads,3,1);
-
-//  w1 = l1->sizeHint().width();
-//  int w2 = l2->sizeHint().width();
-//  w4 = l4->sizeHint().width();
-//  width = (w1 > w2) ? w1 : w2;
-//  width = (width > w4) ? width : w4;
+  grid->addWidget(maxuploads,4,1);
 
   QSize sz2(maxw_sz,downloadbutton->sizeHint().height());
 
@@ -232,14 +223,67 @@ void PropertiesDlg::setupTabs()
 
   addTab(frame,i18n("Up/Down&loads"));
 
-  // tab3 - Misc options --------------------
-  const int rows3 =5;
-  const int cols3 =3;
+  // tab for misc
+  const int rows3 =3;
+  const int cols3 =5;
 
   frame=new QWidget(this);
 
   grid=new QGridLayout(frame,rows3,cols3,5,5);
 
+  l1=new QLabel(i18n("Normal Text"),frame);
+  grid->addWidget(l1,0,0);
+  maxw_sz =  l4->sizeHint().width();
+
+  l2=new QLabel(i18n("Info Text"),frame);
+  grid->addWidget(l2,0,3);
+  maxw_sz =  maxw_sz > l2->sizeHint().width() ? maxw_sz : l2->sizeHint().width();
+
+  l3=new QLabel(i18n("Message Text"),frame);
+  grid->addWidget(l3,1,0);
+  maxw_sz =  maxw_sz > l3->sizeHint().width() ? maxw_sz : l3->sizeHint().width();
+
+  l4=new QLabel(i18n("Error Text"),frame);
+  grid->addWidget(l4,1,3);
+  maxw_sz =  maxw_sz > l4->sizeHint().width() ? maxw_sz : l4->sizeHint().width();
+
+//  l5=new QLabel(i18n("Background"),frame);
+//  grid->addWidget(l5,2,0);
+//  maxw_sz =  maxw_sz > l5->sizeHint().width() ? maxw_sz : l5->sizeHint().width();
+
+  l1->setMaximumWidth(maxw_sz);
+  l2->setMaximumWidth(maxw_sz);
+  l3->setMaximumWidth(maxw_sz);
+  l4->setMaximumWidth(maxw_sz);
+//  l5->setMaximumWidth(maxw_sz);
+
+  normalcol = new KColorButton(frame);
+  grid->addWidget(normalcol,0,1);
+  infocol = new KColorButton(frame);
+  grid->addWidget(infocol,0,4);
+  messagecol = new KColorButton(frame);
+  grid->addWidget(messagecol,1,1);
+  errorcol = new KColorButton(frame);
+  grid->addWidget(errorcol,1,4);
+//  backgroundcol = new KColorButton(frame);
+//  grid->addWidget(backgroundcol,2,1);
+
+  normalcol->setMaximumSize(normalcol->sizeHint());
+  infocol->setMaximumSize(normalcol->sizeHint());
+  messagecol->setMaximumSize(normalcol->sizeHint());
+  errorcol->setMaximumSize(normalcol->sizeHint());
+//  backgroundcol->setMaximumSize(normalcol->sizeHint());
+
+  addTab(frame,i18n("&Console Colors"));
+
+  // tab3 - Misc options --------------------
+  const int rows4 =5;
+  const int cols4 =3;
+
+  frame=new QWidget(this);
+
+  grid=new QGridLayout(frame,rows4,cols4,5,5);
+
   // clear on new search
   clearsearch= new QCheckBox(i18n("Clear searchlist on new search"),frame,"clearsearch");
   grid->addMultiCellWidget(clearsearch,0,0,0,2);
@@ -253,7 +297,6 @@ void PropertiesDlg::setupTabs()
   grid->addMultiCellWidget(multiselect,2,2,0,2);
   multiselect->setMaximumHeight(multiselect->sizeHint().height());
 
-
   l1=new QLabel(i18n("mp3 player command "),frame);
   l1->setMaximumWidth(l1->sizeHint().width());
   grid->addWidget(l1,3,0);
@@ -309,7 +352,7 @@ void PropertiesDlg::setupTabs()
   shareddepth = new QLineEdit(frame, "dirdepth" );
   shareddepth->setMaxLength(1); // up to 9 enough
   grid->addWidget(shareddepth,5,3);
-//  maxw_sz =  shareddepth->sizeHint().width();
+
   shareddepth->setMaximumWidth(shareddepth->sizeHint().width());
 
   QPushButton *addbutton = new QPushButton(i18n("Insert"),frame,"insert");
@@ -317,14 +360,12 @@ void PropertiesDlg::setupTabs()
   connect(addbutton,SIGNAL(clicked()),this,SLOT(addPath()));
   maxw_sz =  addbutton->sizeHint().width();
 
-
   QPushButton *delbutton = new QPushButton(i18n("Delete"),frame,"delete");
   grid->addWidget(delbutton,6,4);
   maxw_sz =  maxw_sz > delbutton->sizeHint().width() ?
         maxw_sz : delbutton->sizeHint().width();
   connect(delbutton,SIGNAL(clicked()),this,SLOT(delPath()));
 
-
   maxw_sz =  maxw_sz > pathbutton->sizeHint().width() ?
      maxw_sz : pathbutton->sizeHint().width();
 
@@ -399,6 +440,8 @@ void PropertiesDlg::browseDownload()
 }
 
 // got the apply/ok button press
+// save the prefs
+//
 void PropertiesDlg::setPrefs()
 {
 #ifdef KDE2
@@ -420,6 +463,7 @@ void PropertiesDlg::setPrefs()
   config->writeEntry("downloaddir",downloaddir->text());
   config->writeEntry("maxuploads",maxuploads->text() ? QString(maxuploads->text()).toInt() : 0 );
   config->writeEntry("maxdownloads",maxdownloads->text() ? QString(maxdownloads->text()).toInt() : 0 );
+  config->writeEntry("downloadtimeout",downloadtimeout->text() ? QString(downloadtimeout->text()).toInt() : 5 );
   config->writeEntry("beeponfinish",beep->isChecked());
  
   config->setGroup("misc");
@@ -428,7 +472,14 @@ void PropertiesDlg::setPrefs()
   config->writeEntry("multiselect",multiselect->isChecked());
  
   config->writeEntry("mp3player",mp3player->text());                 
-  
+
+  config->writeEntry("normalcol",normalcol->color());
+  config->writeEntry("infocol",infocol->color());
+  config->writeEntry("messagecol",messagecol->color());
+  config->writeEntry("errorcol",errorcol->color());
+//  config->writeEntry("backgroundcol",backgroundcol->color());
+
+
 #else
   // tab1
   kapp->getConfig()->writeEntry("username",username->text());
@@ -445,6 +496,7 @@ void PropertiesDlg::setPrefs()
   kapp->getConfig()->writeEntry("downloaddir",downloaddir->text());
   kapp->getConfig()->writeEntry("maxuploads",maxuploads->text() ? QString(maxuploads->text()).toInt() : 0 );
   kapp->getConfig()->writeEntry("maxdownloads",maxdownloads->text() ? QString(maxdownloads->text()).toInt() : 0 );
+  kapp->getConfig()->writeEntry("downloadtimeout",downloadtimeout->text() ? QString(downloadtimeout->text()).toInt() : 5 );
   kapp->getConfig()->writeEntry("beeponfinish",beep->isChecked());
 
   // tab3
@@ -453,6 +505,15 @@ void PropertiesDlg::setPrefs()
   kapp->getConfig()->writeEntry("multiselect",multiselect->isChecked());
 
   kapp->getConfig()->writeEntry("mp3player",mp3player->text());
+
+  // console tab
+  kapp->getConfig()->writeEntry("normalcol",normalcol->color());
+  kapp->getConfig()->writeEntry("infocol",infocol->color());
+  kapp->getConfig()->writeEntry("messagecol",messagecol->color());
+  kapp->getConfig()->writeEntry("errorcol",errorcol->color());
+//  kapp->getConfig()->writeEntry("backgroundcol",backgroundcol->color());
+
+
 #endif /* KDE2 */
 
   //  libpaths
@@ -493,9 +554,17 @@ void PropertiesDlg::getPrefs()
   // tab2
   downloaddir->setText(p.downloaddir);
   maxuploads->setText( QString().setNum(p.maxuploads));
+  downloadtimeout->setText( QString().setNum(p.downloadtimeout));
   maxdownloads->setText( QString().setNum(p.maxdownloads));
   beep->setChecked(p.beep);
 
+  // console prefs
+  normalcol->setColor(p.normalcol);
+  infocol->setColor(p.infocol);
+  messagecol->setColor(p.messagecol);
+  errorcol->setColor(p.errorcol);
+//  backgroundcol->setColor(p.backgroundcol);
+
   // tab3
   clearsearch->setChecked(p.clearsearch);
   showpath->setChecked(p.showpath);
@@ -504,7 +573,6 @@ void PropertiesDlg::getPrefs()
   mp3player->setText(p.mp3player);
 
   // mp3 paths
-//#ifdef KDE2
   QString tmp_path = p.pathlist.first();
   while (tmp_path) {
     QString s1, s2, s3;
@@ -565,10 +633,18 @@ Preferences PropertiesDlg::readPrefs()
    p.maxuploads=config->readNumEntry("maxuploads",0);
    p.beep=config->readBoolEntry("beeponfinish",true);
    p.maxdownloads=config->readNumEntry("maxdownloads",0);
- 
+   p.downloadtimeout=config->readNumEntry("downloadtimeout",5);
+
    // expand the dirs if required
    p.downloaddir=expandFileName(p.downloaddir);
- 
+
+   // console cols
+   p.normalcol=config->readColorEntry("normalcol",&black);
+   p.infocol=config->readColorEntry("infocol",&blue);
+   p.messagecol=config->readColorEntry("messagecol",&green);
+   p.errorcol=config->readColorEntry("errorcol",&red);
+//   p.backgroundcol=config->readColorEntry("backgroundcol",&white);
+
    // Misc
    config->setGroup("misc");
    p.clearsearch=config->readBoolEntry("clearsearch",true);
@@ -609,10 +685,18 @@ Preferences PropertiesDlg::readPrefs()
    p.maxuploads=kapp->getConfig()->readNumEntry("maxuploads",0);
    p.beep=kapp->getConfig()->readBoolEntry("beeponfinish",true);
    p.maxdownloads=kapp->getConfig()->readNumEntry("maxdownloads",0);
+   p.downloadtimeout=kapp->getConfig()->readNumEntry("downloadtimeout",5);
 
    // expand the dirs if required
    p.downloaddir=expandFileName(p.downloaddir);
 
+   // console cols
+   p.normalcol=kapp->getConfig()->readColorEntry("normalcol",&black);
+   p.infocol=kapp->getConfig()->readColorEntry("infocol",&blue);
+   p.messagecol=kapp->getConfig()->readColorEntry("messagecol",&green);
+   p.errorcol=kapp->getConfig()->readColorEntry("errorcol",&red);
+//   p.backgroundcol=kapp->getConfig()->readColorEntry("backgroundcol",&white);
+
    // Misc
    p.clearsearch=kapp->getConfig()->readBoolEntry("clearsearch",true);
    p.showpath=kapp->getConfig()->readBoolEntry("showpath",false);
