@@ -22,8 +22,9 @@
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qcombo.h>
-#include <qlineedit.h>
-#include <qlistview.h>
+//#include <qlineedit.h>
+#include <extlistview.h>
+#include <extlineedit.h>
 #include <qpushbutton.h>
 #ifdef KDE2
 #include <klocale.h>
@@ -37,12 +38,33 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "speedvgood.xpm"
+#include "speedgood.xpm"
+#include "speedaverage.xpm"
+#include "speedbad.xpm"
+
+
 class SearchResultItem : public QListViewItem {
 public:
   SearchResultItem(QListView *parent,const char *s1,const char *s2,const char *s3,
 		   const char *s4,const char *s5,const char *s6,const char *s7)
     : QListViewItem(parent,s1,s2,s3,s4,s5,s6,s7)
-  { }
+  {
+     int speed;
+
+     if(s4) {
+       speed = atoi(s4);
+       /*
+          show a kind of speed indicator - crap really as it is assuming
+          that the user isn't lying about speed - this should be based on
+          ping time
+       */
+       if(speed<1) setPixmap(0,QPixmap((const char **)speedbad_xpm));
+       else if(speed<5) setPixmap(0,QPixmap((const char **)speedaverage_xpm));
+       else if(speed<8) setPixmap(0,QPixmap((const char **)speedgood_xpm));
+       else setPixmap(0,QPixmap((const char **)speedvgood_xpm));
+     }
+  }
 #ifdef KDE2
   virtual QString text(int col) const
 #else
@@ -89,7 +111,7 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
 
   QLabel *l=new QLabel(i18n("Search for "),this);
   maxw_sz =  l->sizeHint().width();
-//**  l->setMaximumWidth( l->sizeHint().width() );
+
   grid->addWidget(l,0,0);
 
   searchoption=new QComboBox(false,this,"searchoption");
@@ -98,21 +120,21 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   searchoption->setMaximumSize( searchoption->sizeHint() );
   basewidth=searchoption->sizeHint().width();
   // all othe ctrls are based on this width
+
   grid->addWidget(searchoption,0,1);
+
   // we want to know when to ghost the other options
   connect(searchoption,SIGNAL(activated(int)),this,SLOT(searchComboActivated(int)));
 
-
-//  searchtext=new QLineEdit(this,"searchtext");
   searchtext=new ExtComboBox(true,this,"searchtext");
   searchtext->setMaxCount(8);
-//  searchtext->setInsertionPolicy(QComboBox::AtTop);
 
-//  searchtext->setMaxLength(60);
+  // return caught to start search
   connect(searchtext,SIGNAL(returnPressed()),this,SLOT(calcSearch()));
 
   grid->addMultiCellWidget(searchtext,0,0,2,4);
 
+  // add search button
   searchbutton=new QPushButton(i18n("Search"),this,"searchbutton");
   searchbutton->setMaximumWidth( basewidth );
   connect(searchbutton,SIGNAL(clicked()),this,SLOT(calcSearch()));
@@ -125,6 +147,7 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
      maxw_sz : l->sizeHint().width();
 
 
+  // create the speed combo
   speedoption=createCompareValueCB("speedoption");
   speedoption->setMaximumHeight( speedoption->sizeHint().height() );
   grid->addWidget(speedoption,1,1);
@@ -146,6 +169,7 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   grid->addWidget(bitrateoption,1,4);
   connect(bitrateoption,SIGNAL(activated(int)),this,SLOT(optionComboActivated(int)));
 
+  // the bitrate combo
   bitratetext=new QComboBox(false,this,"bitratetext");
   bitratetext->insertItem(i18n("64"));
   bitratetext->insertItem(i18n("74"));
@@ -169,11 +193,12 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   grid->addWidget(freqoption,2,1);
   connect(freqoption,SIGNAL(activated(int)),this,SLOT(optionComboActivated(int)));
 
+  // the freq combo
   freqtext=new QComboBox(false,this,"freqtext");
   freqtext->insertItem(i18n("11025"));
   freqtext->insertItem(i18n("22050"));
   freqtext->insertItem(i18n("44100"));
-  freqtext->insertItem(i18n("48800")); //?????????
+  freqtext->insertItem(i18n("48800"));
 
   grid->addWidget(freqtext,2,2);
 
@@ -181,13 +206,14 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   l->setAlignment(AlignRight);
   grid->addWidget(l,2,3);
 
-  resultstext=new QLineEdit(this,"resultstext");
+  resultstext=new ExtLineEdit(this,"resultstext");
   // only allows 100 in napster anyway - more are ignored
   resultstext->setMaxLength(3);
   resultstext->setText(i18n("100"));
   grid->addWidget(resultstext,2,4);
 
-  searchlistview=new QListView(this);
+  // craete and populate the list
+  searchlistview=new ExtListView(this,"searchview");
   searchlistview->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
   searchlistview->addColumn(i18n("file"),280);
   searchlistview->setColumnWidthMode(0,QListView::Manual);
@@ -202,14 +228,19 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   searchlistview->addColumn(i18n("user"),100);
   searchlistview->setColumnWidthMode(5,QListView::Manual);
 
-  searchlistview->setSorting(3); // sort on insertion   ** was -1
+  // sort on insertion  - on connection - ** was -1
+  searchlistview->setSorting(3,false);
 
+  // force a load of the saved list widths
+  searchlistview->loadWidths();
+
+  // default option is to allow multi selects
   multiselect =  true;
   searchlistview->setMultiSelection(true); // allow multi selects
 
   grid->addMultiCellWidget(searchlistview,3,3,0,5);
 
-  // setup the poup
+  // setup the menu popup
 
   searchpopupmenu=new QPopupMenu();
   if(searchpopupmenu) {
@@ -227,9 +258,8 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
   connect(searchlistview,SIGNAL(rightButtonPressed( QListViewItem *, const QPoint &, int )),
        this,SLOT(popupSearch( QListViewItem *, const QPoint &, int )));
 
-
-  // set up the search items as enabled
-  setExtraOptionsEnabled(true);
+  // load in the last sessions search prefs
+  loadSearchPrefs();
 
   // don't show paths as the default
   showsearchpath = false;
@@ -237,6 +267,11 @@ SearchPanel::SearchPanel(QWidget *parent, const char *name )
 SearchPanel::~SearchPanel()
 {
 }
+
+/*
+ * time to do a search - create the search string and send to
+ * interested people
+ */
 void SearchPanel::calcSearch()
 {
   int type=searchoption->currentItem();
@@ -291,7 +326,10 @@ void SearchPanel::calcSearch()
   return;
 }
 
-void SearchPanel::addSearchItem(SongInfo *song /*,bool showsearchpath*/)
+/*
+ * add a song to the search list
+ */
+void SearchPanel::addSearchItem(SongInfo *song)
 {
   if(!song) return;
 
@@ -317,6 +355,9 @@ void SearchPanel::addSearchItem(SongInfo *song /*,bool showsearchpath*/)
 
 }
 
+/*
+ * time to popup the menu
+ */
 void SearchPanel::popupSearch( QListViewItem *i, const QPoint &pos, int col)
 {
   QListViewItem *selecteditem=searchlistview->currentItem();
@@ -330,10 +371,12 @@ void SearchPanel::clearSearch()
   searchlistview->clear();
 }
 
+/*
+ * downlaod has been selected - request dload for each selected item
+ */
 void SearchPanel::popupSearchDownload()
 {
   QListViewItem *item=searchlistview->firstChild();
-  //searchlistview->currentItem();
 
   while(item) {
      if(item->isSelected()) {
@@ -345,45 +388,55 @@ void SearchPanel::popupSearchDownload()
   }
 }
 
+/*
+ * menu selected for ping so ping all selected items
+ */
 void SearchPanel::popupPing()
 {
   QListViewItem *item=searchlistview->firstChild();
 
   while(item) {
      if(item->isSelected()) {
-        // selected so download it
+        // selected so ping it
         emit ping(item->text(5));
-        //searchlistview->setSelected(item,false);
      }
      item = item->nextSibling();
   }
 
 }
 
+/*
+ * menu sel for who is - whois all selected
+ */
 void SearchPanel::popupWhois()
 {
   QListViewItem *item=searchlistview->firstChild();
 
   while(item) {
      if(item->isSelected()) {
-        // selected so download it
+        // selected so whois it
         emit whois(item->text(5));
      }
      item = item->nextSibling();
   }
-
 }
 
-
+/*
+ * get setting for if we wanted to show full apths or not
+ */
 bool SearchPanel::showSearchPath() const
 {
   return showsearchpath;
 }
 
+/*
+ * set whether to show full paths
+ */
 void SearchPanel::setShowSearchPath(bool yes)
 {
   QString s_filename;
 
+  // if setting has changed - we will have to go thru each one and change it
   if(showsearchpath!=yes)
   {
     QListViewItem *it=searchlistview->firstChild();
@@ -400,6 +453,10 @@ void SearchPanel::setShowSearchPath(bool yes)
   }
   return;
 }
+
+/*
+ * set whether to use multiselect or not
+ */
 void SearchPanel::setMultiSelect(bool yes)
 {
   QString s_filename;
@@ -440,8 +497,9 @@ void SearchPanel::searchComboActivated(int v)
 void SearchPanel::optionComboActivated(int v)
 {
   // don't really care about the value here
-  // setExtraOptionsEnabled will handle
-  setExtraOptionsEnabled(true); // we only get this msg if an option was enabled
+  // setExtraOptionsEnabled will handle it
+  setExtraOptionsEnabled(true);
+  // we only get this msg if an option was enabled
 }
 
 // enable/disable the extra search options in the search panel
@@ -465,15 +523,15 @@ void SearchPanel::setExtraOptionsEnabled(bool enable)
   return;
 }
 
-
+// creates a combo box with the items
+// DONT CARE
+// AT LEAST
+// AT BEST
+// EQUAL TO
 QComboBox * SearchPanel::createCompareValueCB(const char *name)
 {
   QComboBox *cb;
-  // creates a combo box with the items
-  // DONT CARE
-  // AT LEAST
-  // AT BEST
-  // EQUAL TO
+
   cb=new QComboBox(false,this,name);
   cb->insertItem(i18n("DONT CARE"));
   cb->insertItem(i18n("AT LEAST"));
@@ -483,6 +541,9 @@ QComboBox * SearchPanel::createCompareValueCB(const char *name)
   return cb;
 }
 
+/*
+ * menu sel for show paths - toggle it
+ */
 void SearchPanel::popupShowPath()
 {
    setShowSearchPath(!showsearchpath);
@@ -493,6 +554,8 @@ QStrList  SearchPanel::getSearchHistory()
 {
    return searchtext->history();
 }
+
+/* set the search history from a string list */
 void SearchPanel::setSearchHistory(const QStrList &str)
 {
   searchtext->insertStrList(&str);
@@ -500,3 +563,102 @@ void SearchPanel::setSearchHistory(const QStrList &str)
   return;
 }
 
+/*
+ * load in the search prefs from the config file
+ */
+void SearchPanel::loadSearchPrefs()
+{
+#ifdef KDE2
+   KConfig *config = KGlobal::config();
+#endif /* KDE2 */
+
+  // set up the past history
+  QStrList list(true);
+#ifdef KDE2
+  config->readListEntry ("history",list);
+#else
+  kapp->getConfig()->readListEntry ("history",list);
+#endif
+
+  setSearchHistory(list);
+
+  setExtraOptionsEnabled(true);
+
+#ifdef KDE2
+  resultstext->setText(config->readEntry("search_results"));
+
+  speedoption->setCurrentItem(config->readNumEntry("search_speedopt",0));
+  bitrateoption->setCurrentItem(config->readNumEntry("search_bitrateopt",0));
+  freqoption->setCurrentItem(config->readNumEntry("search_freqopt",0));
+
+  freqtext->setCurrentItem(config->readNumEntry("search_freq",0));
+  speedtext->setCurrentItem(config->readNumEntry("search_speed",0));
+  bitratetext->setCurrentItem(config->readNumEntry("search_bitrate",0));
+
+  searchoption->setCurrentItem(config->readNumEntry("search_type",0));
+
+  setExtraOptionsEnabled(config->readNumEntry("search_type",0)==0);
+
+#else
+  resultstext->setText(kapp->getConfig()->readEntry("search_results"));
+
+  speedoption->setCurrentItem(kapp->getConfig()->readNumEntry("search_speedopt",0));
+  bitrateoption->setCurrentItem(kapp->getConfig()->readNumEntry("search_bitrateopt",0));
+  freqoption->setCurrentItem(kapp->getConfig()->readNumEntry("search_freqopt",0));
+
+  freqtext->setCurrentItem(kapp->getConfig()->readNumEntry("search_freq",0));
+  speedtext->setCurrentItem(kapp->getConfig()->readNumEntry("search_speed",0));
+  bitratetext->setCurrentItem(kapp->getConfig()->readNumEntry("search_bitrate",0));
+
+  searchoption->setCurrentItem(kapp->getConfig()->readNumEntry("search_type",0));
+
+  setExtraOptionsEnabled(kapp->getConfig()->readNumEntry("search_type",0)==0);
+#endif
+  return;
+}
+/*
+ * save the prefs to the config for next time
+ */
+void SearchPanel::saveSearchPrefs()
+{
+     // save the past search history
+    QStrList str = getSearchHistory();
+
+#ifdef KDE2
+   KConfig *config = KGlobal::config();
+#endif /* KDE2 */
+
+#ifdef KDE2
+    config->writeEntry("history",str);
+#else
+    kapp->getConfig()->writeEntry("history",str);
+#endif
+
+#ifdef KDE2
+  config()->writeEntry("search_freq",freqtext->currentItem());
+  config()->writeEntry("search_speed",speedtext->currentItem());
+  config()->writeEntry("search_bitrate",bitratetext->currentItem());
+
+  config()->writeEntry("search_results",resultstext->text());
+
+  config()->writeEntry("search_speedopt",speedoption->currentItem());
+  config()->writeEntry("search_bitrateopt",bitrateoption->currentItem());
+  config->writeEntry("search_freqopt",freqoption->currentItem());
+
+  config->writeEntry("search_type",searchoption->currentItem());
+#else
+  kapp->getConfig()->writeEntry("search_freq",freqtext->currentItem());
+  kapp->getConfig()->writeEntry("search_speed",speedtext->currentItem());
+  kapp->getConfig()->writeEntry("search_bitrate",bitratetext->currentItem());
+
+  kapp->getConfig()->writeEntry("search_results",resultstext->text());
+
+  kapp->getConfig()->writeEntry("search_speedopt",speedoption->currentItem());
+  kapp->getConfig()->writeEntry("search_bitrateopt",bitrateoption->currentItem());
+  kapp->getConfig()->writeEntry("search_freqopt",freqoption->currentItem());
+
+  kapp->getConfig()->writeEntry("search_type",searchoption->currentItem());
+#endif
+  return;
+}
+
