@@ -23,7 +23,7 @@
 class ExtComboBox;
 class QComboBox;
 class QLineEdit;
-class QListView;
+class ExtListView;
 class QListViewItem;
 class QPoint;
 class KSocket;
@@ -74,10 +74,16 @@ public:
   bool showSearchPath() const;
   void setShowSearchPath(bool yes);
   void setMultiSelect(bool yes);
+
   // save / retrieve search lists from prefs
+  void loadSearchPrefs();
+  void saveSearchPrefs();
+
   QStrList getSearchHistory();
   void setSearchHistory(const QStrList &str);
+
 private:
+
   void setExtraOptionsEnabled(bool enable);
   QComboBox *createCompareValueCB(const char *name);
 
@@ -88,7 +94,7 @@ private:
   ExtComboBox *searchtext;
 
   QComboBox *searchoption;
-  QListView *searchlistview;
+  ExtListView *searchlistview;
   QPushButton *searchbutton;
 
   QComboBox *speedoption;
