@@ -27,7 +27,7 @@
 //
 int sock_connect(int sock,sockaddr *caddr,int sz)
 {
-  struct sockaddr_in saddr;
+//  struct sockaddr_in saddr;
 
 
   return -1;
