@@ -125,11 +125,11 @@ SongInfo *SongInfo::loadSongInfo(const char *fname,bool getall)
   afile.open(IO_ReadOnly);
 
   asong.filename = fname; // **** NOTE: must be a windoze name here
-                      // so convert it to a windows path
+                          // so convert it to a windows path
   if(!afile.isOpen()) return NULL;
 
   asong.size=afile.size();
-//  cout<<fname<<": ";
+
   if(readMP3Header(&afile,&h)) {
     asong.freq = h.freq;
     asong.bitrate = h.bitrate;
@@ -141,7 +141,9 @@ SongInfo *SongInfo::loadSongInfo(const char *fname,bool getall)
     asong.seconds=0;
   }
 
-  if(getall) {
+  // if we want to get it all and we don't yet have the md5
+  if(getall /*&& asong.md5.isEmpty()*/)
+  {
     // calc md5
     afile.at(0); // go to the start
     asong.md5 = calcMD5(&afile) + "-" + QString().setNum(asong.size);
@@ -180,12 +182,11 @@ static int freq_tbl[4][3] = {
   {44100, 48000, 32000}  //MPEG 1
 };
 
-// private func ( not even in the class for determining the header */
+// private func ( not even in the class for determining the header ) */
 bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
 {
 //  0000 0000 0000 0000 0000 0000 0000 0000
 
-//  MP3Header mp3h;
   char tmp[14];
   unsigned long bithdr;
   int trycnt=0;
@@ -194,18 +195,11 @@ bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
 
   afile->readBlock(&tmp[1],3);
 
-//  mp3hdr->sync=0;
-//  mp3hdr->version = 1;
-//  mp3hdr->layer = 0;
-
-//  cout<<"try: ";
   do {
-//    //cout<<"+"<<flush;
     tmp[0]=tmp[1];
     tmp[1]=tmp[2];
     tmp[2]=tmp[3];
     afile->readBlock(&tmp[3],1);
-//    afile->readBlock(&tmp[0],4);
 
     if(trycnt==0 && tmp[0]=='I' && tmp[1]=='D'
        && tmp[2]=='3' && tmp[3]<=0x3) {
@@ -215,15 +209,12 @@ bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
        // look for the possible header
 
        while(tmp[0]!=-1) {
-//       while(tmp[0]!=0xFF) {
          if(afile->atEnd()) return false;
 
          afile->readBlock(&tmp[0],1);
        }
 
-//       tmp[0]=0xff;
        afile->readBlock(&tmp[1],3);
-
     }
 
     bithdr = (unsigned long)(
@@ -245,18 +236,12 @@ bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
       || mp3hdr->layer==0 || mp3hdr->bitrate==0xf
       || mp3hdr->freq==3 );
 
-//  mp3hdr->sync =  bithdr >> 21;
-
-//  mp3hdr->version = ((bithdr >> 19)&0x3);
-//  mp3hdr->layer = ((bithdr >> 17)&0x3);
   mp3hdr->protect = ((bithdr >> 16)&0x1);
 
   // get index & calc brate from it
-//  mp3hdr->bitrate = ((bithdr >> 12)&0xf);
   mp3hdr->bitrate =
       bitrate_tbl[mp3hdr->version & 1][mp3hdr->layer - 1][mp3hdr->bitrate];
 
-//  mp3hdr->freq = ((bithdr >> 10)&0x3);
   mp3hdr->freq =
       freq_tbl[mp3hdr->version][mp3hdr->freq];
 
@@ -268,7 +253,8 @@ bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
   mp3hdr->emphasis = (bithdr & 0x3);
 
   int skip=0;
-// is there a variable bit rate bit
+
+  // is there a variable bit rate bit
   if(mp3hdr->version==3 ) {  // mpeg version 1
      if(mp3hdr->channels==3) skip = 17; // Single Channel
      else skip = 32;
@@ -301,7 +287,7 @@ bool readMP3Header(QFile *afile,MP3Header *mp3hdr)
         (tmp[10] <<  8) |
         (tmp[11]      )
        );
-       // FrameSize = (mpeg1?12:144) * 1000 * BitRate / SampleRate;
+
        float framesize = (float)afile->size() / (float)bithdr;
        mp3hdr->bitrate =
          (int)(( framesize * (float)mp3hdr->freq)
