@@ -17,7 +17,7 @@
 
 #include "uploadpanel.h"
 
-#include <qlistview.h>
+#include <extlistview.h>
 #include <qlayout.h>
 #include <qpopupmenu.h>
 #include <kapp.h>
@@ -39,11 +39,12 @@ UploadPanel::UploadPanel(QWidget *parent, const char *name )
   showuploadpath=true;
 
   QGridLayout *grid=new QGridLayout(this,1,1,5,5);
-  uploadlistview=new QListView(this);
+  uploadlistview=new ExtListView(this,"uploadview");
   uploadlistview->setFrameStyle(QFrame::WinPanel|QFrame::Sunken);
 
   grid->addMultiCellWidget(uploadlistview,0,0,0,0);
 
+  // populate the header
   uploadlistview->addColumn(i18n("file"),200);
   uploadlistview->setColumnWidthMode(0,QListView::Manual);
   uploadlistview->addColumn(i18n("read"),80);
@@ -57,6 +58,8 @@ UploadPanel::UploadPanel(QWidget *parent, const char *name )
   uploadlistview->addColumn(i18n("status"),80);
   uploadlistview->setColumnWidthMode(4,QListView::Manual);
 
+  uploadlistview->loadWidths();
+
   // create the popup menu for the uploadlist view
   uploadpopupmenu=new QPopupMenu();
   if(uploadpopupmenu) {
@@ -76,15 +79,21 @@ UploadPanel::~UploadPanel()
 {
 }
 
+/*
+ * called from popupmenu for a ping
+ */
 void UploadPanel::popupPing()
 {
   QListViewItem *selecteditem=uploadlistview->currentItem();
 
   if(selecteditem) {
-     emit ping(selecteditem->text(4));  //---------------
+     emit ping(selecteditem->text(4));  // let interested people know
   }
 }
 
+/*
+ * on menu sel of whois
+ */
 void UploadPanel::popupWhois()
 {
   QListViewItem *selecteditem=uploadlistview->currentItem();
@@ -93,15 +102,20 @@ void UploadPanel::popupWhois()
      emit whois(selecteditem->text(4));
   }
 }
+/*
+ * on menu sel of play
+ */
 void UploadPanel::popupUploadPlay()
 {
   QListViewItem *selecteditem=uploadlistview->currentItem();
 
   if(selecteditem) {
-     // TODO ********* get the filename associated with this upload
      emit play(selecteditem->text(0));
   }
 }
+/*
+ * on menu sel of terminate
+ */
 void UploadPanel::popupUploadTerminate()
 {
   QListViewItem *selecteditem=uploadlistview->currentItem();
@@ -111,25 +125,35 @@ void UploadPanel::popupUploadTerminate()
   }
 }
 
+/*
+ * clear the items
+ */
 void UploadPanel::clear()
 {
   uploadlistview->clear();
 }
 
+/*
+ * on rmb select - show the menu if on an item
+ */
 void UploadPanel::popupMenu( QListViewItem *i, const QPoint &pos, int col)
 {
   QListViewItem *selecteditem=i;
-  //uploadlistview->currentItem();
+
   if(uploadpopupmenu && selecteditem) {
      uploadlistview->setSelected(selecteditem,true);
      uploadpopupmenu->exec(QCursor::pos());
   }
 }
 
+/*
+ * function to add song to the list
+ */
 void UploadPanel::addUploadItem(SongInfo *song)
 {
   if(!song) return;
 
+  // get name depending on if we want all of the name or not
   QString s_filename;
   if(!showuploadpath) s_filename=getFileName(song->filename);
   else s_filename=song->filename;
@@ -151,6 +175,9 @@ void UploadPanel::addUploadItem(SongInfo *song)
         song->md5);
 }
 
+/*
+ * update the song with new data after finding it in the list
+ */
 void UploadPanel::updateUploadItem(SongInfo *sg)
 {
   if(!sg) return;
@@ -161,19 +188,27 @@ void UploadPanel::updateUploadItem(SongInfo *sg)
 
   QListViewItem *it=uploadlistview->firstChild();
 
+  cerr<<"ul update: looking for "<<sg->filename<<" md5 " << sg->md5 << " ";
+
+  // find the song - assuming the md5 is unique
   while(it) {
      if(sg->md5.findRev(it->text(6))==0) {
+       cerr<<" found it ";
        it->setText(1,convertSize(sg->read));
        it->setText(2,convertSize(sg->size));
        it->setText(3,convertSize(sg->bps));
-       it->setText(5,convertUploadStatus(sg->status)); // status
+       it->setText(5,convertUploadStatus(sg->status));
        break;
      }
      it=it->nextSibling();
   }
+  cerr<<endl<<flush;
 
 }
 
+/*
+ * remove song from the list if it can be found
+ */
 void UploadPanel::removeUploadItem(SongInfo *sg)
 {
   if(!sg) return;
@@ -190,6 +225,9 @@ void UploadPanel::removeUploadItem(SongInfo *sg)
   return;
 }
 
+/*
+ * get the number of items in the panel
+ */
 int UploadPanel::numItems() const
 {
   return uploadlistview->childCount();
